==> haskell-recursion-schemes-5.2.3-135.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-recursion-schemes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recursion-schemes
version:              5.2.3
visibility:           public
id:                   recursion-schemes-5.2.3-CsgKQXBbbOpD4bJHYJxPwO
key:                  recursion-schemes-5.2.3-CsgKQXBbbOpD4bJHYJxPwO
license:              BSD-2-Clause
copyright:            Copyright (C) 2008-2015 Edward A. Kmett
maintainer:
    "Samuel Gélineau" <gelisam@gmail.com>,
    "Ryan Scott" <ryan.gl.scott@gmail.com>,
    "Luc Tielen" <luc.tielen@gmail.com>

author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/recursion-schemes/
synopsis:
    Representing common recursion patterns as higher-order functions

description:
    Many recursive functions share the same structure, e.g. pattern-match on the input and, depending on the data constructor, either recur on a smaller input or terminate the recursion with the base case. Another one: start with a seed value, use it to produce the first element of an infinite list, and recur on a modified seed in order to produce the rest of the list. Such a structure is called a recursion scheme. Using higher-order functions to implement those recursion schemes makes your code clearer, faster, and safer. See README for details.

category:             Control, Recursion
abi:                  9e4d711c1874d83f37bf4d640eabe66b
exposed:              True
exposed-modules:
    Data.Functor.Base Data.Functor.Foldable Data.Functor.Foldable.TH

hidden-modules:       Paths_recursion_schemes
import-dirs:          /usr/lib/ghc-9.6.6/site-local/recursion-schemes-5.2.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/recursion-schemes-5.2.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/recursion-schemes-5.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recursion-schemes
hs-libraries:         HSrecursion-schemes-5.2.3-CsgKQXBbbOpD4bJHYJxPwO
depends:
    base-4.18.2.1 comonad-5.0.9-5bfOfNZGuHK7Og8aLM6Xot containers-0.6.7
    data-fix-0.3.4-DcHJ3ttKSJw5ofwAk9Vr2A
    free-5.2-3fckYVSYEwRA3sQVkSQiQV template-haskell-2.20.0.0
    th-abstraction-0.5.0.0-HAFjiAO2nGN58SdxVZCnLH transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-recursion-schemes/html/recursion-schemes.haddock

haddock-html:         /usr/share/doc/haskell-recursion-schemes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-recursion-schemes-5.2.3-136-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-recursion-schemes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recursion-schemes
version:              5.2.3
visibility:           public
id:                   recursion-schemes-5.2.3-LYYjxK0qcvA3wHQenQbhI
key:                  recursion-schemes-5.2.3-LYYjxK0qcvA3wHQenQbhI
license:              BSD-2-Clause
copyright:            Copyright (C) 2008-2015 Edward A. Kmett
maintainer:
    "Samuel Gélineau" <gelisam@gmail.com>,
    "Ryan Scott" <ryan.gl.scott@gmail.com>,
    "Luc Tielen" <luc.tielen@gmail.com>

author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/recursion-schemes/
synopsis:
    Representing common recursion patterns as higher-order functions

description:
    Many recursive functions share the same structure, e.g. pattern-match on the input and, depending on the data constructor, either recur on a smaller input or terminate the recursion with the base case. Another one: start with a seed value, use it to produce the first element of an infinite list, and recur on a modified seed in order to produce the rest of the list. Such a structure is called a recursion scheme. Using higher-order functions to implement those recursion schemes makes your code clearer, faster, and safer. See README for details.

category:             Control, Recursion
abi:                  37de8b54179c1b68497e88d9c641d102
exposed:              True
exposed-modules:
    Data.Functor.Base Data.Functor.Foldable Data.Functor.Foldable.TH

hidden-modules:       Paths_recursion_schemes
import-dirs:          /usr/lib/ghc-9.6.6/site-local/recursion-schemes-5.2.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/recursion-schemes-5.2.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/recursion-schemes-5.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recursion-schemes
hs-libraries:         HSrecursion-schemes-5.2.3-LYYjxK0qcvA3wHQenQbhI
depends:
    base-4.18.2.1 comonad-5.0.9-715y3Qio4tKCm1VNZVBtRL containers-0.6.7
    data-fix-0.3.4-3won58iaWYcBjetskLCnc9
    free-5.2-CP2SAI6deNWCXG1eD5QmMc template-haskell-2.20.0.0
    th-abstraction-0.5.0.0-HAFjiAO2nGN58SdxVZCnLH transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-recursion-schemes/html/recursion-schemes.haddock

haddock-html:         /usr/share/doc/haskell-recursion-schemes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
